{% load static %}
{% load i18n %}
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="utf-8">
    <title>MySOC</title>
    <meta name="renderer" content="webkit">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <meta name="apple-mobile-web-app-status-bar-style" content="black">
    <meta name="apple-mobile-web-app-capable" content="yes">
    <meta name="format-detection" content="telephone=no">
    <link rel="icon" href="{% static 'console/img/logo.png' %}">
    <link rel="stylesheet" href="{% static 'console/layui/css/layui.css' %}">
    <link rel="stylesheet" href="{% static 'console/css/miniAdmin.css' %}">
</head>

<body class="layui-layout-body layuimini-all">
<div class="layui-layout layui-layout-admin">

    <div class="layui-header header">
        <div class="layui-logo layuimini-logo"></div>

        <div class="layuimini-header-content">
            <a>
                <div class="layuimini-tool"><i title="展开" class="layui-icon layui-icon-shrink-right"
                                               data-side-fold="1"></i></div>
            </a>

            <!--电脑端头部菜单-->
            <ul class="layui-nav layui-layout-left layuimini-header-menu layuimini-menu-header-pc layuimini-pc-show">
            </ul>

            <!--手机端头部菜单-->
            <ul class="layui-nav layui-layout-left layuimini-header-menu layuimini-mobile-show">
                <li class="layui-nav-item">
                    <a href="javascript:;"><i class="fa fa-list-ul"></i> 选择模块</a>
                    <dl class="layui-nav-child layuimini-menu-header-mobile">
                    </dl>
                </li>
            </ul>

            <ul class="layui-nav layui-layout-right">
                <li class="layui-nav-item" lay-unselect>
                    <a href="javascript:;" id="globalSearch" style="font-weight: bold;font-size: 25px"
                       data-search="全局搜索"><i class="layui-icon layui-icon-search"></i></a>
                </li>
                <li class="layui-nav-item" lay-unselect>
                    <a href="javascript:;" data-refresh="刷新"><i class="layui-icon layui-icon-refresh-3"></i></a>
                </li>
                <li class="layui-nav-item" lay-unselect>
                    <a href="javascript:;" data-lang="切换语言"><i class="layui-icon layui-icon-website"></i></a>
                    <dl class="layui-nav-child">
                        <dd>
                            {% get_current_language as LANGUAGE_CODE %}
                            {% get_available_languages as LANGUAGES %}
                            {% get_language_info_list for LANGUAGES as languages %}
                            {% for language in languages %}
                                <a href="i18n/switch/{{ language.code }}"
                                        {% if language.code == LANGUAGE_CODE %}
                                   style="color: #009688"
                                        {% endif %}>
                                    {{ language.name_local }}
                                </a>
                            {% endfor %}
                        </dd>
                    </dl>
                </li>

                <li class="layui-nav-item layuimini-setting">
                    <a href="javascript:;">admin</a>
                    <dl class="layui-nav-child">
                        <dd>
                            <a href="javascript:;" layuimini-content-href="page/user-setting.html" data-title="基本资料"
                               data-icon="fa fa-gears">基本资料<span class="layui-badge-dot"></span></a>
                        </dd>
                        <dd>
                            <a href="javascript:;" layuimini-content-href="page/user-password.html"
                               data-title="修改密码" data-icon="fa fa-gears">修改密码</a>
                        </dd>
                        <dd>
                            <a href="javascript:;" layuimini-content-href="page/user-password.html"
                               data-title="修改密码" data-icon="fa fa-gears">API Token</a>
                        </dd>
                        <dd>
                            <hr>
                        </dd>
                        <dd>
                            <a href="javascript:;" class="login-out">退出登录</a>
                        </dd>
                    </dl>
                </li>
                <li class="layui-nav-item layuimini-select-bgcolor" lay-unselect>
                    <a href="javascript:;"><i class="layui-icon layui-icon-about"></i></a>
                </li>
            </ul>
        </div>
    </div>

    <!--无限极左侧菜单-->
    <div class="layui-side layui-bg-black layuimini-menu-left">
    </div>

    <!--初始化加载层-->
    {#    <div class="layuimini-loader">#}
    {#        <div class="layuimini-loader-inner"></div>#}
    {#    </div>#}

    <!--手机端遮罩层-->
    <div class="layuimini-make"></div>

    <!-- 移动导航 -->
    <div class="layuimini-site-mobile"><i class="layui-icon"></i></div>

    <div class="layui-body">

        <div class="layuimini-tab layui-tab-rollTool layui-tab" lay-filter="layuiminiTab" lay-allowclose="true">
            <ul class="layui-tab-title">
                <li class="layui-this" id="layuiminiHomeTabId" lay-id=""></li>
            </ul>
            <div class="layui-tab-control">
                <li class="layuimini-tab-roll-left layui-icon layui-icon-left"></li>
                <li class="layuimini-tab-roll-right layui-icon layui-icon-right"></li>
                <li class="layui-tab-tool layui-icon layui-icon-down">
                    <ul class="layui-nav close-box">
                        <li class="layui-nav-item">
                            <a href="javascript:;"><span class="layui-nav-more"></span></a>
                            <dl class="layui-nav-child">
                                <dd><a href="javascript:;" layuimini-tab-close="current">关 闭 当 前</a></dd>
                                <dd><a href="javascript:;" layuimini-tab-close="other">关 闭 其 他</a></dd>
                                <dd><a href="javascript:;" layuimini-tab-close="all">关 闭 全 部</a></dd>
                            </dl>
                        </li>
                    </ul>
                </li>
            </div>
            <div class="layui-tab-content">
                <div id="layuiminiHomeTabIframe" class="layui-tab-item layui-show"></div>
            </div>
        </div>

    </div>
</div>

<script src="{% static 'console/layui/layui.js' %}" charset="utf-8"></script>
<script src="{% static 'console/js/console.js' %}" charset="utf-8"></script>
<script>
    layui.use(['jquery', 'layer', 'miniAdmin'], function () {
        let $ = layui.jquery,
            layer = layui.layer,
            miniAdmin = layui.miniAdmin;

        let options = {
            initUrl: "{% url 'console:console_menu' %}",    // 初始化接口
            clearUrl: "clear",    // 缓存清理接口
            urlHashLocation: true,      // 是否打开hash定位
            multiModule: false,          // 是否开启多模块
            menuChildOpen: false,       // 是否默认展开菜单
            loadingTime: 1,             // 初始化加载时间
            pageAnim: true,             // iframe窗口动画
            maxTabNum: 30,              // 最大的tab打开数量
        };
        miniAdmin.render(options);

        $('#globalSearch').on('click', function (event) {
            miniAdmin.miniTab.openNewTabByIframe({
                href: 'global_search',
                title: '全局搜索',
            })
        })


        $('.login-out').on("click", function () {
            layer.msg('退出登录成功', {icon: 1, time: 1000}, function () {
                window.location = "{% url 'console:console_logout' %}";
            });
        });
    });
</script>
</body>
</html>